Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Add ¶
Add creates a new RandomParagraphApp Controller and adds it to the Manager with default RBAC. The Manager will set fields on the Controller and Start it when the Manager is Started.
func ContainsString ¶
ContainsString checks if a string is contained in a slice
Types ¶
type ReconcileRandomParagraphApp ¶
ReconcileRandomParagraphApp reconciles a RandomParagraphApp object
func (*ReconcileRandomParagraphApp) Reconcile ¶
func (r *ReconcileRandomParagraphApp) Reconcile(request reconcile.Request) (reconcile.Result, error)
Reconcile reads that state of the cluster for a RandomParagraphApp object and makes changes based on the state read and what is in the RandomParagraphApp.Spec Automatically generate RBAC rules to allow the Controller to read and write Deployments +kubebuilder:rbac:groups=,resources=pods,verbs=get;list;watch;create;update;patch;delete +kubebuilder:rbac:groups=,resources=services,verbs=get;list;watch;create;update;patch;delete +kubebuilder:rbac:groups=random.acme.com,resources=randomparagraphapps,verbs=get;list;watch;create;update;patch;delete +kubebuilder:rbac:groups=events.k8s.io,resources=events,verbs=get;list;watch;create;update;patch;delete